package com.ruoyi.mall.mapper;

import java.util.List;
import com.ruoyi.mall.domain.MallAppGoodsUnit;

/**
 * app商品单位Mapper接口
 * 
 * @author ruoyi
 * @date 2024-07-02
 */
public interface MallAppGoodsUnitMapper 
{
    /**
     * 查询app商品单位
     * 
     * @param goodsUnitId app商品单位主键
     * @return app商品单位
     */
    public MallAppGoodsUnit selectMallAppGoodsUnitByGoodsUnitId(Long goodsUnitId);

    /**
     * 查询app商品单位列表
     * 
     * @param mallAppGoodsUnit app商品单位
     * @return app商品单位集合
     */
    public List<MallAppGoodsUnit> selectMallAppGoodsUnitList(MallAppGoodsUnit mallAppGoodsUnit);

    /**
     * 新增app商品单位
     * 
     * @param mallAppGoodsUnit app商品单位
     * @return 结果
     */
    public int insertMallAppGoodsUnit(MallAppGoodsUnit mallAppGoodsUnit);

    /**
     * 修改app商品单位
     * 
     * @param mallAppGoodsUnit app商品单位
     * @return 结果
     */
    public int updateMallAppGoodsUnit(MallAppGoodsUnit mallAppGoodsUnit);

    /**
     * 删除app商品单位
     * 
     * @param goodsUnitId app商品单位主键
     * @return 结果
     */
    public int deleteMallAppGoodsUnitByGoodsUnitId(Long goodsUnitId);

    /**
     * 批量删除app商品单位
     * 
     * @param goodsUnitIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteMallAppGoodsUnitByGoodsUnitIds(Long[] goodsUnitIds);
}
